==> pipewire-docs-1%3A0.3.33-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pwtest.js <==
var group__pwtest =
[
    [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", [
      [ "dlls", "structpwtest__spa__plugin.html#adc8a853d256b3dca56a3e805dc96c5b4", null ],
      [ "handles", "structpwtest__spa__plugin.html#a8bb79b9b0e5cb045fa2686edde9c3d34", null ],
      [ "ndlls", "structpwtest__spa__plugin.html#a22553184b5d864e926e17d976cffca9f", null ],
      [ "nhandles", "structpwtest__spa__plugin.html#aef8a87ec887314f7a70366be56138406", null ],
      [ "nsupport", "structpwtest__spa__plugin.html#ad517984d1206a29ad28eb83f19f41dbe", null ],
      [ "support", "structpwtest__spa__plugin.html#ae819473de8479871a6cd78f10a97ce68", null ]
    ] ],
    [ "pwtest_context", "structpwtest__context.html", null ],
    [ "pwtest_suite", "structpwtest__suite.html", null ],
    [ "pwtest_test", "structpwtest__test.html", null ],
    [ "PWTEST", "group__pwtest.html#gadf579902bf3375a739c90fe2aaf8fd89", null ],
    [ "pwtest_add", "group__pwtest.html#ga9e4d1f396fc7bb5a2aa37977f562fdbd", null ],
    [ "pwtest_bool_eq", "group__pwtest.html#ga67d03b7d6a735f8d4568ddda45a200f9", null ],
    [ "pwtest_bool_false", "group__pwtest.html#gab0d6a401804bf140b7d5ff5381b9deca", null ],
    [ "pwtest_bool_ne", "group__pwtest.html#ga1f365422ab4403a3f3799b3667e01ff4", null ],
    [ "pwtest_bool_true", "group__pwtest.html#ga51c9bca0ae9864feb3aa5ec79d7e1e71", null ],
    [ "pwtest_double_eq", "group__pwtest.html#ga60aaaf4bca029a7cd77d9e2328cc33b0", null ],
    [ "pwtest_double_ge", "group__pwtest.html#gaf3b84c537a532605e175d8b72c8c09b5", null ],
    [ "pwtest_double_gt", "group__pwtest.html#ga54e354518bf9333c3c92c8556ad0c328", null ],
    [ "pwtest_double_le", "group__pwtest.html#ga73a6c78f94e35f2b7789268c01ef11c2", null ],
    [ "pwtest_double_lt", "group__pwtest.html#ga1536e136ab274b09533862681ddf8075", null ],
    [ "pwtest_double_ne", "group__pwtest.html#gaee50852e8a274fef83f1edce58d3f6fd", null ],
    [ "pwtest_errno", "group__pwtest.html#ga66c238ea82ddcd0fc1228b79084c8bd4", null ],
    [ "pwtest_errno_ok", "group__pwtest.html#ga0a5763242fdbf0a7a007ca67ee40e8d0", null ],
    [ "pwtest_error_with_msg", "group__pwtest.html#gaeec2e3bbe8d82887f6695b6320d4bfe7", null ],
    [ "pwtest_fail", "group__pwtest.html#ga288f936c9cb1fea769e8fcf616650ba5", null ],
    [ "pwtest_fail_if_reached", "group__pwtest.html#ga88063ae0fab66efabacf14f923e18bbf", null ],
    [ "pwtest_fail_with_msg", "group__pwtest.html#ga10ad32a379491ecbbb15bb8bc1f7f803", null ],
    [ "pwtest_int", "group__pwtest.html#ga95d448892acab98bc574b2b390d03c84", null ],
    [ "pwtest_int_eq", "group__pwtest.html#ga30b74c4eb3256e1c351bb036cb338990", null ],
    [ "pwtest_int_ge", "group__pwtest.html#ga7817ddf65dee003c061bc129ef2e68cd", null ],
    [ "pwtest_int_gt", "group__pwtest.html#gab465d70253d093ecf30b9f67810c2c78", null ],
    [ "pwtest_int_le", "group__pwtest.html#ga45b76d40140c645308b3759dfc351ada", null ],
    [ "pwtest_int_lt", "group__pwtest.html#ga8c8507f28d70a45a43c2fdcec7f0e94b", null ],
    [ "pwtest_int_ne", "group__pwtest.html#gaf532763be82ce75af6128f9878790541", null ],
    [ "pwtest_neg_errno", "group__pwtest.html#gae989df52a5f9588eb41600181c6c55b3", null ],
    [ "pwtest_neg_errno_ok", "group__pwtest.html#gac310509558c790446945fac0ba8816ef", null ],
    [ "pwtest_ptr_eq", "group__pwtest.html#gae428daf5df9a2ad60685437bc53ed225", null ],
    [ "pwtest_ptr_ne", "group__pwtest.html#ga2c915fce91d56c38b5f5a3c4e58c43b2", null ],
    [ "pwtest_ptr_notnull", "group__pwtest.html#ga235878471a0cc9e96ec3a167cd154f53", null ],
    [ "pwtest_ptr_null", "group__pwtest.html#gaad5435bd5350f7c71336cf9bbb8ae5e1", null ],
    [ "pwtest_str_eq", "group__pwtest.html#ga5729ceef65ee401eb01e0a5a882eb3bc", null ],
    [ "pwtest_str_eq_n", "group__pwtest.html#ga93a9c0f32540724de5543cfd2f174190", null ],
    [ "pwtest_str_ne", "group__pwtest.html#ga725688a342b197bd0ba624c8c28f04e1", null ],
    [ "pwtest_str_ne_n", "group__pwtest.html#ga31aadf049c2da1eaa5735511d1cafef6", null ],
    [ "PWTEST_SUITE", "group__pwtest.html#gaa6bff674d1cc33233873ed2c924c08f4", null ],
    [ "pwtest_arg", "group__pwtest.html#gade1f1e873e503e06753f6af83f3a2572", [
      [ "PWTEST_NOARG", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572afabeafe2a772e4127462b11c4fa95c74", null ],
      [ "PWTEST_ARG_SIGNAL", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572a74cdf71fff95432caf0645976d656245", null ],
      [ "PWTEST_ARG_RANGE", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572ad4bca28b8b1e3424b49c10e601e202dd", null ],
      [ "PWTEST_ARG_PROP", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572a2fe7797d3fbaf4dea350377dc35186de", null ],
      [ "PWTEST_ARG_ENV", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572aba7e7e83113904f9c8027ad90948672f", null ],
      [ "PWTEST_ARG_DAEMON", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572aae21e1c777cbf83c1e99b21429c2c29b", null ]
    ] ],
    [ "pwtest_result", "group__pwtest.html#gabad6d78654322100450231d26e9b8bbe", [
      [ "PWTEST_PASS", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea1f7cd195aece8f9db397f985484ba19c", null ],
      [ "PWTEST_FAIL", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbeac70e58d73cdd0409332b6bab68476fc4", null ],
      [ "PWTEST_SKIP", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea61da86daedb6b8a14a66d067d6a5f80b", null ],
      [ "PWTEST_TIMEOUT", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea2adb9316fc9054e6abcb5b7077547f72", null ],
      [ "PWTEST_SYSTEM_ERROR", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea7bc8412d2615b98bc997590e2e065f5f", null ]
    ] ],
    [ "pwtest_get_context", "group__pwtest.html#ga6c3897c5d38a1242f613ad25bd7e5fb2", null ],
    [ "pwtest_get_iteration", "group__pwtest.html#ga135297caa69f5e14b2b20148850d080b", null ],
    [ "pwtest_get_props", "group__pwtest.html#gad3be15a2f7839d732014d8c6306d1dc0", null ],
    [ "pwtest_mkstemp", "group__pwtest.html#ga5a5ba20824f92f66f86a8d1656db0ea5", null ],
    [ "pwtest_spa_plugin_destroy", "group__pwtest.html#ga3abfb07ed321c803757a34edcf56ef73", null ],
    [ "pwtest_spa_plugin_load_interface", "group__pwtest.html#ga3bbb310188bdc3fa6323b4194995f886", null ],
    [ "pwtest_spa_plugin_new", "group__pwtest.html#ga6acce8dd835b0f3d69d3e248593afe85", null ],
    [ "pwtest_spa_plugin_try_load_interface", "group__pwtest.html#ga7e85c98847c3522c3494af29a21f1e75", null ]
];

==> pipewire-docs-1%3A0.3.39-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/group__pwtest.js <==
var group__pwtest =
[
    [ "pwtest.h", "pwtest_8h.html", null ],
    [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", [
      [ "nsupport", "structpwtest__spa__plugin.html#ad517984d1206a29ad28eb83f19f41dbe", null ],
      [ "support", "structpwtest__spa__plugin.html#ae819473de8479871a6cd78f10a97ce68", null ],
      [ "ndlls", "structpwtest__spa__plugin.html#a22553184b5d864e926e17d976cffca9f", null ],
      [ "dlls", "structpwtest__spa__plugin.html#adc8a853d256b3dca56a3e805dc96c5b4", null ],
      [ "nhandles", "structpwtest__spa__plugin.html#aef8a87ec887314f7a70366be56138406", null ],
      [ "handles", "structpwtest__spa__plugin.html#a8bb79b9b0e5cb045fa2686edde9c3d34", null ]
    ] ],
    [ "pwtest_context", "structpwtest__context.html", null ],
    [ "pwtest_suite", "structpwtest__suite.html", null ],
    [ "pwtest_test", "structpwtest__test.html", null ],
    [ "pwtest_fail", "group__pwtest.html#ga288f936c9cb1fea769e8fcf616650ba5", null ],
    [ "pwtest_fail_if_reached", "group__pwtest.html#ga88063ae0fab66efabacf14f923e18bbf", null ],
    [ "pwtest_fail_with_msg", "group__pwtest.html#ga10ad32a379491ecbbb15bb8bc1f7f803", null ],
    [ "pwtest_error_with_msg", "group__pwtest.html#gaeec2e3bbe8d82887f6695b6320d4bfe7", null ],
    [ "pwtest_errno_ok", "group__pwtest.html#ga0a5763242fdbf0a7a007ca67ee40e8d0", null ],
    [ "pwtest_errno", "group__pwtest.html#ga66c238ea82ddcd0fc1228b79084c8bd4", null ],
    [ "pwtest_neg_errno_ok", "group__pwtest.html#gac310509558c790446945fac0ba8816ef", null ],
    [ "pwtest_neg_errno", "group__pwtest.html#gae989df52a5f9588eb41600181c6c55b3", null ],
    [ "pwtest_bool_eq", "group__pwtest.html#ga67d03b7d6a735f8d4568ddda45a200f9", null ],
    [ "pwtest_bool_ne", "group__pwtest.html#ga1f365422ab4403a3f3799b3667e01ff4", null ],
    [ "pwtest_bool_true", "group__pwtest.html#ga51c9bca0ae9864feb3aa5ec79d7e1e71", null ],
    [ "pwtest_bool_false", "group__pwtest.html#gab0d6a401804bf140b7d5ff5381b9deca", null ],
    [ "pwtest_int_eq", "group__pwtest.html#ga30b74c4eb3256e1c351bb036cb338990", null ],
    [ "pwtest_int_ne", "group__pwtest.html#gaf532763be82ce75af6128f9878790541", null ],
    [ "pwtest_int_lt", "group__pwtest.html#ga8c8507f28d70a45a43c2fdcec7f0e94b", null ],
    [ "pwtest_int_le", "group__pwtest.html#ga45b76d40140c645308b3759dfc351ada", null ],
    [ "pwtest_int_ge", "group__pwtest.html#ga7817ddf65dee003c061bc129ef2e68cd", null ],
    [ "pwtest_int_gt", "group__pwtest.html#gab465d70253d093ecf30b9f67810c2c78", null ],
    [ "pwtest_ptr_eq", "group__pwtest.html#gae428daf5df9a2ad60685437bc53ed225", null ],
    [ "pwtest_ptr_ne", "group__pwtest.html#ga2c915fce91d56c38b5f5a3c4e58c43b2", null ],
    [ "pwtest_ptr_null", "group__pwtest.html#gaad5435bd5350f7c71336cf9bbb8ae5e1", null ],
    [ "pwtest_ptr_notnull", "group__pwtest.html#ga235878471a0cc9e96ec3a167cd154f53", null ],
    [ "pwtest_double_eq", "group__pwtest.html#ga60aaaf4bca029a7cd77d9e2328cc33b0", null ],
    [ "pwtest_double_ne", "group__pwtest.html#gaee50852e8a274fef83f1edce58d3f6fd", null ],
    [ "pwtest_double_lt", "group__pwtest.html#ga1536e136ab274b09533862681ddf8075", null ],
    [ "pwtest_double_le", "group__pwtest.html#ga73a6c78f94e35f2b7789268c01ef11c2", null ],
    [ "pwtest_double_ge", "group__pwtest.html#gaf3b84c537a532605e175d8b72c8c09b5", null ],
    [ "pwtest_double_gt", "group__pwtest.html#ga54e354518bf9333c3c92c8556ad0c328", null ],
    [ "pwtest_int", "group__pwtest.html#ga95d448892acab98bc574b2b390d03c84", null ],
    [ "pwtest_str_eq", "group__pwtest.html#ga5729ceef65ee401eb01e0a5a882eb3bc", null ],
    [ "pwtest_str_eq_n", "group__pwtest.html#ga93a9c0f32540724de5543cfd2f174190", null ],
    [ "pwtest_str_ne", "group__pwtest.html#ga725688a342b197bd0ba624c8c28f04e1", null ],
    [ "pwtest_str_ne_n", "group__pwtest.html#ga31aadf049c2da1eaa5735511d1cafef6", null ],
    [ "pwtest_str_contains", "group__pwtest.html#gade999a9a24a6f9690e1003ee704c8cb7", null ],
    [ "pwtest_add", "group__pwtest.html#ga9e4d1f396fc7bb5a2aa37977f562fdbd", null ],
    [ "PWTEST", "group__pwtest.html#gadf579902bf3375a739c90fe2aaf8fd89", null ],
    [ "PWTEST_SUITE", "group__pwtest.html#gaa6bff674d1cc33233873ed2c924c08f4", null ],
    [ "pwtest_result", "group__pwtest.html#gabad6d78654322100450231d26e9b8bbe", [
      [ "PWTEST_PASS", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea1f7cd195aece8f9db397f985484ba19c", null ],
      [ "PWTEST_FAIL", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbeac70e58d73cdd0409332b6bab68476fc4", null ],
      [ "PWTEST_SKIP", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea61da86daedb6b8a14a66d067d6a5f80b", null ],
      [ "PWTEST_TIMEOUT", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea2adb9316fc9054e6abcb5b7077547f72", null ],
      [ "PWTEST_SYSTEM_ERROR", "group__pwtest.html#ggabad6d78654322100450231d26e9b8bbea7bc8412d2615b98bc997590e2e065f5f", null ]
    ] ],
    [ "pwtest_arg", "group__pwtest.html#gade1f1e873e503e06753f6af83f3a2572", [
      [ "PWTEST_NOARG", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572afabeafe2a772e4127462b11c4fa95c74", null ],
      [ "PWTEST_ARG_SIGNAL", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572a74cdf71fff95432caf0645976d656245", null ],
      [ "PWTEST_ARG_RANGE", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572ad4bca28b8b1e3424b49c10e601e202dd", null ],
      [ "PWTEST_ARG_PROP", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572a2fe7797d3fbaf4dea350377dc35186de", null ],
      [ "PWTEST_ARG_ENV", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572aba7e7e83113904f9c8027ad90948672f", null ],
      [ "PWTEST_ARG_DAEMON", "group__pwtest.html#ggade1f1e873e503e06753f6af83f3a2572aae21e1c777cbf83c1e99b21429c2c29b", null ]
    ] ],
    [ "pwtest_get_iteration", "group__pwtest.html#ga135297caa69f5e14b2b20148850d080b", null ],
    [ "pwtest_get_props", "group__pwtest.html#gae28b2ed45d205b93298f6c85f9cf6913", null ],
    [ "pwtest_get_context", "group__pwtest.html#ga7f5e4cd81dea4d1c31d004e3c48c597a", null ],
    [ "pwtest_spa_plugin_new", "group__pwtest.html#ga1108ba45f915c9df17cc28357a21f5bf", null ],
    [ "pwtest_spa_plugin_destroy", "group__pwtest.html#ga3abfb07ed321c803757a34edcf56ef73", null ],
    [ "pwtest_spa_plugin_load_interface", "group__pwtest.html#ga0bc59dec6ed4bae2c6c03aea2c8789ae", null ],
    [ "pwtest_spa_plugin_try_load_interface", "group__pwtest.html#ga7e85c98847c3522c3494af29a21f1e75", null ],
    [ "pwtest_mkstemp", "group__pwtest.html#ga5a5ba20824f92f66f86a8d1656db0ea5", null ]
];
